==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_9/jsd_f0f7b6e1e4e159e7a40001fc3e649dfc.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center UpdatePowerProfileByIDV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorF0F7B6E1E4E159E7A40001Fc3E649Dfc(object):
    """UpdatePowerProfileByIDV1 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorF0F7B6E1E4E159E7A40001Fc3E649Dfc, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "profileName": {
                "type": "string"
                },
                "rules": {
                "items": {
                "properties": {
                "interfaceID": {
                "enum": [
                "GigabitEthernet0",
                "GigabitEthernet1",
                "LAN 1",
                "LAN 2",
                "LAN 3",
                "6 GHz",
                "5 GHz",
                "Secondary 5 GHz",
                "2.4 GHz",
                "USB 0"
                ],
                "type": "string"
                },
                "interfaceType": {
                "enum": [
                "Ethernet",
                "Radio",
                "USB"
                ],
                "type": "string"
                },
                "parameterType": {
                "enum": [
                "Speed",
                "Spatial Stream",
                "State"
                ],
                "type": "string"
                },
                "parameterValue": {
                "enum": [
                "5000 MBPS",
                "2500 MBPS",
                "1000 MBPS",
                "100 MBPS",
                "8\u00d78",
                "4\u00d74",
                "3\u00d73",
                "2\u00d72",
                "1\u00d71",
                "Disable"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v3_1_3_0/jsd_f0f7b6e1e4e159e7a40001fc3e649dfc.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdatePowerProfileByID data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorF0F7B6E1E4E159E7A40001Fc3E649Dfc(object):
    """UpdatePowerProfileByID request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorF0F7B6E1E4E159E7A40001Fc3E649Dfc, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "profileName": {
                "type": "string"
                },
                "rules": {
                "items": {
                "properties": {
                "interfaceID": {
                "enum": [
                "GIGABITETHERNET0",
                "GIGABITETHERNET1",
                "LAN1",
                "LAN2",
                "LAN3",
                "6GHZ",
                "5GHZ",
                "SECONDARY_5GHZ",
                "2_4GHZ",
                "USB0"
                ],
                "type": "string"
                },
                "interfaceType": {
                "enum": [
                "ETHERNET",
                "RADIO",
                "USB"
                ],
                "type": "string"
                },
                "parameterType": {
                "enum": [
                "SPEED",
                "SPATIALSTREAM",
                "STATE"
                ],
                "type": "string"
                },
                "parameterValue": {
                "enum": [
                "5000MBPS",
                "2500MBPS",
                "1000MBPS",
                "100MBPS",
                "EIGHT_BY_EIGHT",
                "FOUR_BY_FOUR",
                "THREE_BY_THREE",
                "TWO_BY_TWO",
                "ONE_BY_ONE",
                "DISABLE"
                ],
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
